@@ -39,20 +39,17 @@
 
 #include <moveit/macros/class_forward.h>
 #include <moveit/robot_state/robot_state.h>
+#include <moveit/utils/moveit_error_code.h>
 #include <moveit_msgs/msg/robot_trajectory.hpp>
 #include <moveit_msgs/msg/robot_state.hpp>
 #include <moveit_msgs/msg/planner_interface_description.hpp>
 #include <moveit_msgs/msg/constraints.hpp>
 #include <moveit_msgs/msg/grasp.hpp>
-// #include <moveit_msgs/msg/place_location.hpp>
-
-// #include <moveit_msgs/action/pickup.hpp>
-// #include <moveit_msgs/action/place.hpp>
 #include <moveit_msgs/action/move_group.hpp>
 #include <moveit_msgs/action/execute_trajectory.hpp>
 
 #include <moveit_msgs/msg/motion_plan_request.hpp>
-#include <geometry_msgs/msg/pose_stamped.h>
+#include <geometry_msgs/msg/pose_stamped.hpp>
 
 #include <rclcpp_action/rclcpp_action.hpp>
 
@@ -60,41 +57,14 @@
 #include <utility>
 #include <tf2_ros/buffer.h>
 
-#include "moveit_move_group_interface_export.h"
+#include <moveit_move_group_interface_export.h>
 
 namespace moveit
 {
 /** \brief Simple interface to MoveIt components */
 namespace planning_interface
 {
-class MoveItErrorCode : public moveit_msgs::msg::MoveItErrorCodes
-{
-public:
-  MoveItErrorCode()
-  {
-    val = 0;
-  }
-  MoveItErrorCode(int code)
-  {
-    val = code;
-  }
-  MoveItErrorCode(const moveit_msgs::msg::MoveItErrorCodes& code)
-  {
-    val = code.val;
-  }
-  explicit operator bool() const
-  {
-    return val == moveit_msgs::msg::MoveItErrorCodes::SUCCESS;
-  }
-  bool operator==(const int c) const
-  {
-    return val == c;
-  }
-  bool operator!=(const int c) const
-  {
-    return val != c;
-  }
-};
+using MoveItErrorCode [[deprecated("Use moveit::core::MoveItErrorCode")]] = moveit::core::MoveItErrorCode;
 
 MOVEIT_CLASS_FORWARD(MoveGroupInterface);  // Defines MoveGroupInterfacePtr, ConstPtr, WeakPtr... etc
 
@@ -113,23 +83,23 @@ public:
   struct Options
   {
     Options(std::string group_name, std::string desc = ROBOT_DESCRIPTION, std::string move_group_namespace = "")
-      : group_name_(std::move(group_name))
-      , robot_description_(std::move(desc))
-      , move_group_namespace_(std::move(move_group_namespace))
+      : group_name(std::move(group_name))
+      , robot_description(std::move(desc))
+      , move_group_namespace(std::move(move_group_namespace))
     {
     }
 
     /// The group to construct the class instance for
-    std::string group_name_;
+    std::string group_name;
 
     /// The robot description parameter name (if different from default)
-    std::string robot_description_;
+    std::string robot_description;
 
     /// Optionally, an instance of the RobotModel to use can be also specified
-    moveit::core::RobotModelConstPtr robot_model_;
+    moveit::core::RobotModelConstPtr robot_model;
 
     /// The namespace for the move group node
-    std::string move_group_namespace_;
+    std::string move_group_namespace;
   };
 
   MOVEIT_STRUCT_FORWARD(Plan);
@@ -138,13 +108,13 @@ public:
   struct Plan
   {
     /// The full starting state used for planning
-    moveit_msgs::msg::RobotState start_state_;
+    moveit_msgs::msg::RobotState start_state;
 
     /// The trajectory of the robot (may not contain joints that are the same as for the start_state_)
-    moveit_msgs::msg::RobotTrajectory trajectory_;
+    moveit_msgs::msg::RobotTrajectory trajectory;
 
     /// The amount of time it took to generate the plan
-    double planning_time_;
+    double planning_time;
   };
 
   /**
@@ -726,7 +696,7 @@ public:
   /** \brief Plan and execute a trajectory that takes the group of joints declared in the constructor to the specified
      target.
       This call is not blocking (does not wait for the execution of the trajectory to complete). */
-  MoveItErrorCode asyncMove();
+  moveit::core::MoveItErrorCode asyncMove();
 
   /** \brief Get the move_group action client used by the \e MoveGroupInterface.
       The client can be used for querying the execution state of the trajectory and abort trajectory execution
@@ -738,24 +708,48 @@ public:
      target.
       This call is always blocking (waits for the execution of the trajectory to complete) and requires an asynchronous
      spinner to be started.*/
-  MoveItErrorCode move();
+  moveit::core::MoveItErrorCode move();
 
   /** \brief Compute a motion plan that takes the group declared in the constructor from the current state to the
      specified
       target. No execution is performed. The resulting plan is stored in \e plan*/
-  MoveItErrorCode plan(Plan& plan);
+  moveit::core::MoveItErrorCode plan(Plan& plan);
 
-  /** \brief Given a \e plan, execute it without waiting for completion. */
-  MoveItErrorCode asyncExecute(const Plan& plan);
+  /** \brief Given a \e plan, execute it without waiting for completion.
+   *  \param [in] plan The motion plan for which to execute
+   *  \param [in] controllers An optional list of ros2_controllers to execute with. If none, MoveIt will attempt to find
+   * a controller. The exact behavior of finding a controller depends on which MoveItControllerManager plugin is active.
+   *  \return moveit::core::MoveItErrorCode::SUCCESS if successful
+   */
+  moveit::core::MoveItErrorCode asyncExecute(const Plan& plan,
+                                             const std::vector<std::string>& controllers = std::vector<std::string>());
 
-  /** \brief Given a \e robot trajectory, execute it without waiting for completion. */
-  MoveItErrorCode asyncExecute(const moveit_msgs::msg::RobotTrajectory& trajectory);
+  /** \brief Given a \e robot trajectory, execute it without waiting for completion.
+   *  \param [in] trajectory The trajectory to execute
+   *  \param [in] controllers An optional list of ros2_controllers to execute with. If none, MoveIt will attempt to find
+   * a controller. The exact behavior of finding a controller depends on which MoveItControllerManager plugin is active.
+   *  \return moveit::core::MoveItErrorCode::SUCCESS if successful
+   */
+  moveit::core::MoveItErrorCode asyncExecute(const moveit_msgs::msg::RobotTrajectory& trajectory,
+                                             const std::vector<std::string>& controllers = std::vector<std::string>());
 
-  /** \brief Given a \e plan, execute it while waiting for completion. */
-  MoveItErrorCode execute(const Plan& plan);
+  /** \brief Given a \e plan, execute it while waiting for completion.
+   *  \param [in] plan Contains trajectory info as well as metadata such as a RobotModel.
+   *  \param [in] controllers An optional list of ros2_controllers to execute with. If none, MoveIt will attempt to find
+   * a controller. The exact behavior of finding a controller depends on which MoveItControllerManager plugin is active.
+   *  \return moveit::core::MoveItErrorCode::SUCCESS if successful
+   */
+  moveit::core::MoveItErrorCode execute(const Plan& plan,
+                                        const std::vector<std::string>& controllers = std::vector<std::string>());
 
-  /** \brief Given a \e robot trajectory, execute it while waiting for completion. */
-  MoveItErrorCode execute(const moveit_msgs::msg::RobotTrajectory& trajectory);
+  /** \brief Given a \e robot trajectory, execute it while waiting for completion.
+   *  \param [in] trajectory The trajectory to execute
+   *  \param [in] controllers An optional list of ros2_controllers to execute with. If none, MoveIt will attempt to find
+   * a controller. The exact behavior of finding a controller depends on which MoveItControllerManager plugin is active.
+   *  \return moveit::core::MoveItErrorCode::SUCCESS if successful
+   */
+  moveit::core::MoveItErrorCode execute(const moveit_msgs::msg::RobotTrajectory& trajectory,
+                                        const std::vector<std::string>& controllers = std::vector<std::string>());
 
   /** \brief Compute a Cartesian path that follows specified waypoints with a step size of at most \e eef_step meters
       between end effector configurations of consecutive points in the result \e trajectory. The reference frame for the
@@ -810,21 +804,6 @@ public:
       in \e request */
   void constructMotionPlanRequest(moveit_msgs::msg::MotionPlanRequest& request);
 
-  /** \brief Build a PickupGoal for an object named \e object and store it in \e goal_out */
-
-  //  moveit_msgs::action::Pickup::Goal constructPickupGoal(const std::string& object,
-  //                                                      std::vector<moveit_msgs::msg::Grasp> grasps,
-  //                                                      bool plan_only) const;
-  //
-  //  /** \brief Build a PlaceGoal for an object named \e object and store it in \e goal_out */
-  //  moveit_msgs::action::Place::Goal constructPlaceGoal(const std::string& object,
-  //                                                    std::vector<moveit_msgs::msg::PlaceLocation> locations,
-  //                                                    bool plan_only) const;
-  //
-  //  /** \brief Convert a vector of PoseStamped to a vector of PlaceLocation */
-  //  std::vector<moveit_msgs::msg::PlaceLocation>
-  //  posesToPlaceLocations(const std::vector<geometry_msgs::msg::PoseStamped>& poses) const;
-
   /**@}*/
 
   /**
@@ -832,77 +811,6 @@ public:
    */
   /**@{*/
 
-  /** \brief Pick up an object
-
-      This applies a number of hard-coded default grasps */
-  //  MoveItErrorCode pick(const std::string& object, bool plan_only = false)
-  //  {
-  //    return pick(constructPickupGoal(object, std::vector<moveit_msgs::msg::Grasp>(), plan_only));
-  //  }
-  //
-  /** \brief Pick up an object given a grasp pose */
-  //  MoveItErrorCode pick(const std::string& object, const moveit_msgs::msg::Grasp& grasp, bool plan_only = false)
-  //  {
-  //    return pick(constructPickupGoal(object, { grasp }, plan_only));
-  //  }
-  //
-  /** \brief Pick up an object given possible grasp poses */
-  //  MoveItErrorCode pick(const std::string& object, std::vector<moveit_msgs::msg::Grasp> grasps, bool plan_only =
-  //  false)
-  //  {
-  //    return pick(constructPickupGoal(object, std::move(grasps), plan_only));
-  //  }
-
-  /** \brief Pick up an object given a PickupGoal
-
-      Use as follows: first create the goal with constructPickupGoal(), then set \e possible_grasps and any other
-      desired variable in the goal, and finally pass it on to this function */
-
-  // MoveItErrorCode pick(const moveit_msgs::action::Pickup::Goal& goal);
-
-  /** \brief Pick up an object
-
-      calls the external moveit_msgs::srv::GraspPlanning service "plan_grasps" to compute possible grasps */
-  // MoveItErrorCode planGraspsAndPick(const std::string& object = "", bool plan_only = false);
-
-  /** \brief Pick up an object
-      calls the external moveit_msgs::srv::GraspPlanning service "plan_grasps" to compute possible grasps */
-  // MoveItErrorCode planGraspsAndPick(const moveit_msgs::msg::CollisionObject& object, bool plan_only = false);
-
-  /** \brief Place an object somewhere safe in the world (a safe location will be detected) */
-  //  MoveItErrorCode place(const std::string& object, bool plan_only = false)
-  //  {
-  //    return place(constructPlaceGoal(object, std::vector<moveit_msgs::msg::PlaceLocation>(), plan_only));
-  //  }
-
-  /** \brief Place an object at one of the specified possible locations */
-  //  MoveItErrorCode place(const std::string& object, std::vector<moveit_msgs::msg::PlaceLocation> locations,
-  //                        bool plan_only = false)
-  //  {
-  //    return place(constructPlaceGoal(object, std::move(locations), plan_only));
-  //  }
-
-  /** \brief Place an object at one of the specified possible locations */
-  //  MoveItErrorCode place(const std::string& object, const std::vector<geometry_msgs::msg::PoseStamped>& poses,
-  //                        bool plan_only = false)
-  //  {
-  //    return place(constructPlaceGoal(object, posesToPlaceLocations(poses), plan_only));
-  //  }
-
-  /** \brief Place an object at one of the specified possible location */
-  //  MoveItErrorCode place(const std::string& object, const geometry_msgs::msg::PoseStamped& pose, bool plan_only =
-  //  false)
-  //  {
-  //    return place(constructPlaceGoal(object, posesToPlaceLocations({ pose }), plan_only));
-  //  }
-
-  /** \brief Place an object given a PlaceGoal
-
-      Use as follows: first create the goal with constructPlaceGoal(), then set \e place_locations and any other
-      desired variable in the goal, and finally pass it on to this function */
-
-  // MoveItErrorCode place(const moveit_msgs::action::Place::Goal& goal);
-
   /** \brief Given the name of an object in the planning scene, make
       the object attached to a link of the robot.  If no link name is
       specified, the end-effector is used. If there is no
